@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -22,6 +20,7 @@
 import logging
 import sys
 from operator import methodcaller
+from pathlib import Path
 
 from boltons.ecoutils import get_profile
 from boltons.iterutils import unique
@@ -29,7 +28,7 @@ from boltons.iterutils import unique
 # Canonical name of the CLI.
 CLI_NAME = "mdedup"
 
-__version__ = "6.0.0"
+__version__ = "6.1.0"
 
 
 # Environment data.
@@ -161,6 +160,13 @@ class Config:
             assert min(ascii_indexes) >= 33
         self.hash_headers = tuple(normalized_headers)
 
+        # Export mail box will always be created from scratch and is not
+        # expected to exists in the first place.
+        if self.export:
+            self.export = Path(self.export).resolve()
+            if self.export.exists():
+                raise FileExistsError(self.export)
+
     def __getattr__(self, attr_id):
         """ Expose configuration entries as properties. """
         if attr_id in self.conf:
